==================
Installation
==================

The fsharadar module can be installed with a pip command as::
  
    $ pip install cython fsharadar

The installtion setup also includes dependencies on the primary platform
components, such as `Zipline <https://github.com/quantopian/zipline>`_
framewotk and `Alphalens <https://github.com/quantopian/alphalens>`_
post-processing library and subsequently installs
the entire Zipline-based research platform. 
    



